.. _credits:


Credits
-------

**Developers**:

`James Nightingale <https://github.com/Jammy2211>`_: Lead developer & PyAutoLens guru.

`Richard Hayes <https://github.com/rhayes777>`_: Lead developer & `PyAutoFit <https://github.com/rhayes777/PyAutoFit>`_ guru.

`Jacob Kegerreis <https://github.com/jkeger>`_: arCTIc

Richard Massey: arCTIc

